Apply .clangformat to all repo source files

Change-Id: I7e79c6058f0303f9a98911e3b7dd2e8596079344


[ROCm/hip commit: 1ba06f63c4]
This commit is contained in:
Maneesh Gupta
2018-03-12 11:29:03 +05:30
parent 52506ef382
commit 4f42ee762d
293 changed files with 43980 additions and 45830 deletions
@@ -24,22 +24,22 @@ THE SOFTWARE.
#include "hip/hcc_detail/hip_complex.h"
#define LEN 64
#define SIZE 64<<2
#define SIZE 64 << 2
__global__ void getSqAbs(hipLaunchParm lp, float *A, float *B, float *C){
__global__ void getSqAbs(hipLaunchParm lp, float* A, float* B, float* C) {
int tx = threadIdx.x + blockIdx.x * blockDim.x;
C[tx] = hipCsqabsf(make_hipFloatComplex(A[tx], B[tx]));
}
int main(){
int main() {
float *A, *Ad, *B, *Bd, *C, *Cd;
A = new float[LEN];
B = new float[LEN];
C = new float[LEN];
for(uint32_t i=0;i<LEN;i++){
A[i] = i*1.0f;
B[i] = i*1.0f;
C[i] = i*1.0f;
for (uint32_t i = 0; i < LEN; i++) {
A[i] = i * 1.0f;
B[i] = i * 1.0f;
C[i] = i * 1.0f;
}
hipMalloc((void**)&Ad, SIZE);
@@ -49,5 +49,5 @@ int main(){
hipMemcpy(Bd, B, SIZE, hipMemcpyHostToDevice);
hipLaunchKernel(getSqAbs, dim3(1), dim3(LEN), 0, 0, Ad, Bd, Cd);
hipMemcpy(C, Cd, SIZE, hipMemcpyDeviceToHost);
std::cout<<A[11]<<" "<<B[11]<<" "<<C[11]<<std::endl;
std::cout << A[11] << " " << B[11] << " " << C[11] << std::endl;
}